#===============================================================================
# GRAPHICS
# 1. histograms log response ratio
# 2. log response ratio of species richness as a function of size and age
# 3. log response ratio of species richness as a function of fish group
# 4. global map of included marine protected areas
# 3. histograms of marine protected areas size and age distribution
# 4. compare size distribution against global database (WDPA)
# 4. check for grain size induced bias
#===============================================================================

# load packages
library(rnaturalearth)
library(rnaturalearthdata)
library(rgeos)
library(sf)
  # sf settings
  world <- ne_countries(scale = "medium", returnclass = "sf")
  sf_use_s2(FALSE)
library(ggspatial)
library(scales)

# source/read in data
source('./modeling.R')
dat_all0 <- read_xlsx("Map_data.xlsx", na = c("","NA"))
dat_WDPA <- read.csv("WDPA_Oct2022_Public_csv.csv", na = c("","NA"), dec = ".", sep = ",") # WDPA database

# prepare data sets
dat_all0$ID <- as.factor(dat_all0$ID) # change to factor
dat_all0$Network <- as.factor(dat_all0$Network) # change to factor
dat_all0$`Sampled individually` <- as.factor(dat_all0$`Sampled individually`) # change to factor
dat_all0 <- dat_all0[!is.na(dat_all0$long),] # delete rows without information on longitude
dat_all0 <- dat_all0[!is.na(dat_all0$protection),] # delete rows without information on protection type
dat_all <- dat_all0 %>% # select distinct protected areas
  select(ID, name_mpa, location, lat, long, protection, mpa_age, size_km2, Network, `Sampled individually`) %>%
  distinct()

dat_WDPA$IUCN_CAT <- as.factor(dat_WDPA$IUCN_CAT) # change to factor
dat_WDPA$STATUS <- as.factor(dat_WDPA$STATUS) # change to factor
dat_WDPA$NO_TAKE <- as.factor(dat_WDPA$NO_TAKE) # change to factor
dat_WDPA <- subset(dat_WDPA, STATUS != "Proposed") # include only protected areas that are already established
dat_WDPA <- subset(dat_WDPA, REP_M_AREA != 0) # include only protected areas that have area specified

dat_WDPA_fp <- subset(dat_WDPA, NO_TAKE == "All")
dat_WDPA_fp <- dat_WDPA_fp[,c(5,10,13,20)] # extract columns of interest
names(dat_WDPA_fp)[names(dat_WDPA_fp) == 'REP_M_AREA'] <- 'area_km2' # rename column

dat_WDPA_pp <- subset(dat_WDPA, NO_TAKE != "All")
dat_WDPA_pp <- dat_WDPA_pp %>% rowwise() %>%
  mutate(area_km2 = (REP_M_AREA-NO_TK_AREA))
dat_WDPA_pp <- subset(dat_WDPA_pp, area_km2 != 0) 
dat_WDPA_pp <- subset(dat_WDPA_pp, area_km2 > 0) # include only protected areas that are not no-take
dat_WDPA_pp <- dat_WDPA_pp[,c(5,10,13,20,32)] # extract columns of interest



# Annotations (create labels) --------------------------------------------------

annA <- grobTree(textGrob("a", x=0.05,  y=0.90, hjust=0, gp=gpar(fontsize=20, fontface="bold")))
annA.s <- grobTree(textGrob("a", x=0.2,  y=0.90, hjust=0, gp=gpar(fontsize=20, fontface="bold")))
annA_map <- grobTree(textGrob("a", x=0.05,  y=0.93, hjust=0, gp=gpar(fontsize=20, fontface="bold")))
annB <- grobTree(textGrob("b", x=0.05,  y=0.90, hjust=0, gp=gpar(fontsize=20, fontface="bold")))
annC <- grobTree(textGrob("c", x=0.05,  y=0.90, hjust=0, gp=gpar(fontsize=20, fontface="bold")))
annD <- grobTree(textGrob("d", x=0.05,  y=0.90, hjust=0, gp=gpar(fontsize=20, fontface="bold")))


# histograms log response ratio --------------------------------

    # richness
        # extract means and CIs
        est_null <- summary(m_SR_null)
        CI_null <- confint.merMod(m_SR_null, method = "profile", oldNames = FALSE)
        CI_null <- CI_null %>%
          as.data.frame(t(CI_null)) %>%
          add_column(protection = c("del", "del", "y")) %>%
          filter(!str_detect(protection, "del")) %>%
          add_column(mean = c(est_null$coefficients[1])) %>%
          dplyr::rename("lci" = "2.5 %", "uci" = "97.5 %")
    
        # plot
        logRR_hist_SR <- ggplot(SR_dat, aes(x=logRR)) +
          geom_histogram( binwidth=0.02, fill="grey", color="darkgrey", size = 1) +
          geom_rect(data=CI_null, aes(xmin=CI_null[1,1], xmax=CI_null[1,2], ymin=0, ymax=7), fill="black", alpha=0.5, inherit.aes = FALSE) +
          geom_segment(aes(x = 0, y = 0, xend = 0, yend = 7), size=0.5, linetype="longdash") + # 0
          geom_segment(aes(x = CI_null[1,4], y = 0, xend = CI_null[1,4], yend = 7), size=0.8, color = "black") + # mean
          annotation_custom(annA) +
          ggtitle("Species richness") +
          xlab("Log response ratio") +
          ylab("Number of MPAs") +
          theme(panel.background = element_rect(fill = 'white'),
                panel.grid.major = element_line(colour = "lightgrey"),
                panel.grid.minor = element_line(colour = "white"),
                panel.border = element_rect(fill = NA,colour = "black"), 
                plot.background = element_rect(fill = 'white'),
                strip.background = element_rect(fill = "white"),
                plot.title = element_text(size = 12),
                axis.text.x = element_text(color="black"),
                axis.text.y = element_text(color="black"))
  
    # shannon diversity
        # extract means and CIs
        est_null_Shan <- summary(m_Shan_null)
        CI_null_Shan <- confint.merMod(m_Shan_null, method = "profile", oldNames = FALSE)
        CI_null_Shan <- CI_null_Shan %>%
          as.data.frame(t(CI_null_Shan)) %>%
          add_column(protection = c("del", "del", "y")) %>%
          filter(!str_detect(protection, "del")) %>%
          add_column(mean = c(est_null_Shan$coefficients[1])) %>%
          dplyr::rename("lci" = "2.5 %", "uci" = "97.5 %")
        
        # plot
        logRR_hist_Shan <- ggplot(Shan_dat, aes(x=logRR)) +
          geom_histogram( binwidth=0.03, fill="grey", color="darkgrey", size = 1) +
          geom_rect(data=CI_null_Shan, aes(xmin=CI_null_Shan[1,1], xmax=CI_null_Shan[1,2], ymin=0, ymax=4), fill="black", alpha=0.5, inherit.aes = FALSE) +
          geom_segment(aes(x = 0, y = 0, xend = 0, yend = 4), size=0.5, linetype="longdash") + # 0
          geom_segment(aes(x = CI_null_Shan[1,4], y = 0, xend = CI_null_Shan[1,4], yend = 4), size=0.8, color = "black") + # mean
          annotation_custom(annB) +
          ggtitle("Shannon entropy") +
          xlab("Log response ratio") +
          ylab("Number of MPAs") +
          theme(panel.background = element_rect(fill = 'white'),
                panel.grid.major = element_line(colour = "lightgrey"),
                panel.grid.minor = element_line(colour = "white"),
                panel.border = element_rect(fill = NA,colour = "black"), 
                plot.background = element_rect(fill = 'white'),
                strip.background = element_rect(fill = "white"),
                plot.title = element_text(size = 12),
                axis.text.x = element_text(color="black"),
                axis.text.y = element_text(color="black"))
  
    pdf("Hists_shannon_SR.pdf", height = 5.5, width = 5)
    grid.arrange(logRR_hist_SR, logRR_hist_Shan)
    dev.off()

  
# log response ratio of species richness as a function of size and age -----------------------

    # size
        # prepare
        effects_size <- effects::effect(term = "c_size_log_km2", mod = m_SR_size, 
                                        xlevels = list(c_size_log_km2 = c(-8.011828977,	-2.441577895,-0.007964539,2.451274364,4.929518990)))
        x_size <- as.data.frame(effects_size)
        x_size$size_km2 <- c(0.008,2.100,23.940,280.000,3337.690)
        
        # plot
        point_size1 <- ggplot() + 
          geom_ribbon(data= x_size, aes(x = size_km2, ymin=lower, ymax=upper), alpha= 0.4, fill="darkgrey") +
          geom_point(data=SR_dat, aes(size_km2, logRR)) + 
          geom_line(data=x_size, aes(x=size_km2, y=fit), color="black", lwd = 1.25) +
          geom_hline(yintercept = 0, lty = 1, color = "black", size = 0.5) +
          scale_x_continuous(trans = 'log10') +
          coord_cartesian(xlim = c(0.2, NA)) +
          ylab(element_blank()) +
          xlab(element_blank()) +
          theme(panel.background = element_rect(fill = 'white'),
                panel.grid.major = element_line(colour = "lightgrey"),
                panel.grid.minor = element_line(colour = "white"),
                panel.border = element_rect(fill = NA,colour = "black"), 
                plot.background = element_rect(fill = 'white'),
                strip.background = element_rect(fill = "white"),
                plot.title = element_text(size = 14),
                axis.text.y = element_blank(),
                axis.ticks.y=element_blank(),
                axis.text.x = element_text(color="black"),
                axis.text.y = element_text(color="black"))
        
        point_size2 <- ggplot() + 
          geom_ribbon(data= x_size, aes(x = size_km2, ymin=lower, ymax=upper), alpha= 0.4, fill="darkgrey") +
          geom_point(data=SR_dat, aes(size_km2, logRR)) + 
          geom_line(data=x_size, aes(x=size_km2, y=fit), color="black", lwd = 1.25) +
          geom_hline(yintercept = 0, lty = 1, color = "black", size = 0.5) +
          annotation_custom(annA.s) +
          scale_x_continuous(trans = 'log10', breaks=c(0.008)) +
          coord_cartesian(xlim = c(0.005, 0.015)) +
          labs(y= "Log response ratio", x = element_blank()) +
          theme(panel.background = element_rect(fill = 'white'),
                panel.grid.major = element_line(colour = "lightgrey"),
                panel.grid.minor = element_line(colour = "white"),
                panel.border = element_rect(fill = NA,colour = "black"), 
                plot.background = element_rect(fill = 'white'),
                strip.background = element_rect(fill = "white"),
                plot.title = element_text(size = 12),
                axis.text.x = element_text(color="black"),
                axis.text.y = element_text(color="black"))
    
      lay.size <- rbind(c(1,1,2,2,2,2,2,2,2))
      
      sizeplot <- grid.arrange(point_size2, point_size1, layout_matrix = lay.size, 
                               bottom = grid::textGrob(expression(paste("Area in ", km^2, "")), y = 0, vjust = -1.2, gp=gpar(fontsize=11)))
  
    # age
        # prepare
        effects_age <- effects::effect(term = "c_age_log", mod = m_SR_age, 
                                       xlevels = list(c_age_log = c(-2.152037071,-0.611592030,-0.115155144,0.577992037,1.393741539)))
        x_age <- as.data.frame(effects_age)
        x_age$mpa_age <- c(1.5,7.0,11.5,23,52)
        
        # plot
        point_age <- ggplot() + 
          geom_ribbon(data= x_age, aes(x = mpa_age, ymin=lower, ymax=upper), alpha= 0.4, fill="darkgrey") +
          geom_point(data=SR_dat, aes(mpa_age, logRR)) + 
          geom_line(data=x_age, aes(x=mpa_age, y=fit), color="black", lwd = 1.25) +
          geom_hline(yintercept = 0, lty = 1, color = "black", size = 0.5) +
          annotation_custom(annB) +
          scale_x_continuous(trans = 'log10') +
          labs(y= "Log response ratio", x = "Duration of protection in years") +
          theme(panel.background = element_rect(fill = 'white'),
                panel.grid.major = element_line(colour = "lightgrey"),
                panel.grid.minor = element_line(colour = "white"),
                panel.border = element_rect(fill = NA,colour = "black"), 
                plot.background = element_rect(fill = 'white'),
                strip.background = element_rect(fill = "white"),
                plot.title = element_text(size = 14),
                axis.text.x = element_text(color="black"),
                axis.text.y = element_text(color="black"))
      
    pdf("results_panel.pdf", width = 5, height = 6)
    grid.arrange(sizeplot, point_age)
    dev.off()
    

# log response ratio of species richness as a function of fish group -----------------------------
  
    # extract means and CIs
    est_FishSR <- summary(m_SR_size)
    CI_FishSR <- confint.merMod(m_SR_size, method = "profile", oldNames = FALSE)
    CI_FishSR <- CI_FishSR %>%
      as.data.frame(t(CI_FishSR)) %>%
      add_column(fishgroup = c("del", "del", "all", "commercial", "non_commercial", "del")) %>%
      filter(!str_detect(fishgroup, "del")) %>%
      add_column(mean = c(est_FishSR$coefficients[1], 
                          est_FishSR$coefficients[1] + est_FishSR$coefficients[2], 
                          est_FishSR$coefficients[1] + est_FishSR$coefficients[3])) %>%
      dplyr::rename("lci" = "2.5 %", "uci" = "97.5 %")
    CI_FishSR[2,1] <- CI_FishSR[1,1] + CI_FishSR[2,1];
    CI_FishSR[2,2] <- CI_FishSR[1,2] + CI_FishSR[2,2];
    CI_FishSR[3,1] <- CI_FishSR[1,1] + CI_FishSR[3,1];
    CI_FishSR[3,2] <- CI_FishSR[1,2] + CI_FishSR[3,2];
    
    # plot
    CI_plot_fish_SR <- ggplot(data = CI_FishSR) +
      geom_point(aes(x=fishgroup, y=mean), color= "black", size = 3) +
      geom_errorbar(aes(x=fishgroup, ymin=lci, ymax= uci), width = 0, color ="black", size = 1) +
      geom_text(aes(x=fishgroup, y=lci, label = round(lci,3.2)), size= 3, vjust = 1.5) +
      geom_text(aes(x=fishgroup, y=uci, label = round(uci,3.2)), size= 3, vjust = -1, hjust = -0.15) +
      geom_text(aes(x=fishgroup, y=mean, label = round(mean,3.2)), size= 4, vjust = -1) +
      geom_text(x=0.85, y=0.45, label="n = 13", size = 4) +
      geom_text(x=1.85, y=0.74, label="n = 15", size = 4) +
      geom_text(x=2.85, y=0.28, label="n = 88", size = 4) +
      theme_classic() +
      scale_x_discrete(limits = rev, labels = c("non- \ncommercial", "commercial", "all")) +
      labs(x= "Fish subgroup", y = "Log response ratio (species richness)") +
      scale_y_continuous(limits=c(-0.4, 0.9)) +
      geom_hline(yintercept=0, color="black", linetype="dashed", alpha=1) +
      coord_flip() +
      theme(plot.background = element_rect(fill = 'white'),
            panel.background = element_rect(fill = 'white'),
            axis.text.x = element_text(color="black"),
            axis.text.y = element_text(color="black"))
  
    pdf("CI_FishSR.pdf", height = 3, width = 6.5)
    grid.arrange(CI_plot_fish_SR)
    dev.off()


# map ------------------------------------------------

    # plot
    map <- ggplot() +
      geom_sf(data = world, fill = '#c9c9c9', colour = '#c9c9c9') +
      geom_point(data=dat_all, aes(x=long, y=lat, shape=protection), 
                 alpha=1, size=3, color = "black") +
      coord_sf(xlim = c(-180, 180), ylim = c(-60, 90), expand = FALSE) +
      scale_shape_manual(name='Protection', values=c(1, 5),
                        labels=c("full", "partial")) +
      #scale_fill_manual(name='Protection', values=c("#FAFDF6", "#353535"),
      #                  labels=c("full", "partial")) +
      xlab('Longitude') +
      ylab('Latitude') +
      annotation_custom(annA_map) +
      theme(legend.position = 'bottom',
            legend.direction = 'horizontal',
            legend.key = element_blank(),
            panel.background = element_rect(fill = 'white'),
            plot.margin = margin(),
            plot.title = element_text(size = 15),
            panel.border = element_rect(colour = "black", fill=NA),
            axis.text.x = element_text(color="black"),
            axis.text.y = element_text(color="black"))

    

# sampled oceans --------------------------------------

  oceans <- dat_all0 %>%
    select(ID, Ocean) %>%
    distinct()
  
  oceansSR <- subset(dat_all0, index == "SR")
  oceansH <- subset(dat_all0, index == "Shannon")
  
  oceansSR <- oceansSR %>%
    select(ID, Ocean) %>%
    distinct()
  
  oceansH <- oceansH %>%
    select(ID, Ocean) %>%
    distinct()
  
  oceans_count <- oceans %>% group_by(Ocean) %>%
    summarise(n_studies = n_distinct(ID))
  
  oceans_countSR <- oceansSR %>% group_by(Ocean) %>%
    summarise(n_studies = n_distinct(ID))
  
  oceans_countH <- oceansH %>% group_by(Ocean) %>%
    summarise(n_studies = n_distinct(ID))

  
# histograms MPA characteristics -----------------------------------

    # age
    hist_age <- ggplot(SR_dat, aes(x = mpa_age, fill = protection)) + 
      geom_histogram(binwidth = 0.025) +
      scale_x_log10() +
      scale_fill_manual(values = c("#c9c9c9", "#3D3D3D"), name="protection",
                        labels=c("fp", "pp")) +
      xlab(expression(paste("Duration of protection in years"))) +
      ylab("Number of MPAs") +
      annotation_custom(annB) +
      theme(axis.title.y = element_text(angle = 90)) +
      theme(panel.background = element_rect(fill = 'white'),
            panel.grid.major = element_line(colour = "lightgrey"),
            panel.grid.minor = element_line(colour = "white"),
            panel.border = element_rect(fill = NA,colour = "black"),
            plot.background = element_rect(fill = 'white'),
            strip.background = element_rect(fill = "white"),
            legend.position = "none",
            axis.text.x = element_text(color="black"),
            axis.text.y = element_text(color="black"))
  
    # size
    no_sci <- function(l) {
      l <- format(l, scientific = FALSE)
      parse(text=l)
    }
    
    hist_size <- ggplot(SR_dat, aes(x = size_km2, fill = protection)) + 
      geom_histogram(binwidth = 0.09) +
      scale_fill_manual(values = c("#c9c9c9", "#3D3D3D"), name="Protection",
                        labels=c("full", "partial")) +
      xlab(expression(paste("Area in ", km^2, ""))) +
      ylab("Number of MPAs") +
      scale_x_continuous(trans = 'log10', labels = no_sci) +
      annotation_custom(annC) +
      theme(axis.title.y = element_text(angle = 90),) +
      theme(panel.background = element_rect(fill = 'white'),
            panel.grid.major = element_line(colour = "lightgrey"),
            panel.grid.minor = element_line(colour = "white"),
            panel.border = element_rect(fill = NA,colour = "black"),
            plot.background = element_rect(fill = 'white'),
            strip.background = element_rect(fill = "white"),
            legend.position = "left",
            plot.title = element_text(size = 14),
            plot.subtitle = element_text(size = 13),
            axis.text.x = element_text(color="black"),
            axis.text.y = element_text(color="black"))
  
    # build layer for grid.arrange (1) map, (2) histogram age, (3) histogram size
    lay <- rbind(c(1),
                 c(1),
                 c(1),
                 c(1),
                 c(1),
                 c(2,2,2,2,3,3,3,3,3),
                 c(2,2,2,2,3,3,3,3,3),
                 c(2,2,2,2,3,3,3,3,3))
    
    # export as PDF file
    pdf("mpa_characteristics.pdf", width = 9.5, height = 7.5)
    grid.arrange(layout_matrix = lay,  map, hist_age, hist_size)
    dev.off()

  
# comparison MPA size (against WDPA database) --------------------------------------

    # create subsets for fully and partially protected areas
    SR_dat_fp <- subset(SR_dat, protection == "fp")
    SR_dat_pp <- subset(SR_dat, protection == "pp")
    
    # plot
        # density plot fully protected
        den_size_fp <- ggplot() +
          geom_density(aes(size_km2, fill = "Our"), alpha = .2, data = SR_dat_fp) +
          geom_density(aes(area_km2, fill = "WDPA"), alpha = .3, data = dat_WDPA_fp) +
          scale_fill_manual(name = "Dataset", values = c(Our = "#E59500", WDPA = "#2A3C24")) +
          xlab(expression(paste("Area (fully protected) in ", km^2, ""))) +
          ylab("Density") +
          ylim(0,0.5) +
          scale_x_continuous(trans = 'log10', limits = (c(0.000001, 1000000)), labels = comma) +
          annotate("text", x = 0.0001, y = 0.3, label = "n (WDPA) = 668  \n n (this study) = 56") +
          theme(axis.title.y = element_text(angle = 90)) +
          annotation_custom(annA) +
          theme(panel.background = element_rect(fill = 'white'),
                panel.grid.major = element_line(colour = "lightgrey"),
                panel.grid.minor = element_line(colour = "white"),
                panel.border = element_rect(fill = NA,colour = "black"),
                plot.background = element_rect(fill = 'white'),
                strip.background = element_rect(fill = "white"),
                legend.position = "none",
                plot.title = element_text(size = 14),
                plot.subtitle = element_text(size = 13),
                axis.text.x = element_text(color="black"),
                axis.text.y = element_text(color="black"))
        
        # density plot partially protected
        den_size_pp <- ggplot() +
          geom_density(aes(size_km2, fill = "This study"), alpha = .3, data = SR_dat_pp) +
          geom_density(aes(area_km2, fill = "WDPA"), alpha = .3, data = dat_WDPA_pp) +
          scale_fill_manual(name = "Dataset", values = c("This study" = "#E59500", WDPA = "#2A3C24")) +
          xlab(expression(paste("Area (partially protected) in ", km^2, ""))) +
          ylab("Density") +
          ylim(0,0.5) +
          scale_x_continuous(trans = 'log10', limits = (c(0.000001, 1000000)), labels = comma) +
          annotate("text", x = 0.0001, y = 0.3, label = "n (WDPA) = 4175\n n (this study) = 36") +
          theme(axis.title.y = element_text(angle = 90)) +
          annotation_custom(annB) +
          theme(panel.background = element_rect(fill = 'white'),
                panel.grid.major = element_line(colour = "lightgrey"),
                panel.grid.minor = element_line(colour = "white"),
                panel.border = element_rect(fill = NA,colour = "black"),
                plot.background = element_rect(fill = 'white'),
                strip.background = element_rect(fill = "white"),
                legend.position = "left",
                plot.title = element_text(size = 14),
                plot.subtitle = element_text(size = 13),
                axis.text.x = element_text(color="black"),
                axis.text.y = element_text(color="black"))
      
    # export as PDF file  
    lay <- rbind(c(2,2,2,2,3,3,3,3,3),
                 c(2,2,2,2,3,3,3,3,3),
                 c(2,2,2,2,3,3,3,3,3))
     
    pdf("mpa_size_density.pdf", width = 9.5, height = 3.75)
    grid.arrange(layout_matrix = lay, den_size_fp, den_size_pp)
    dev.off()

  
# check for grain-size induced bias (log response ratio ~ grain area) ---------------------

    # plot
    grain_lrr <- ggplot() + 
      geom_point(data=SR_dat, aes(grain_area_m, logRR, color = "Richness")) + 
      geom_smooth(data = SR_dat, formula = y ~ x, aes(grain_area_m, logRR), method=lm , color="#9D9D9D", se=FALSE) +
      geom_point(data=Shan_dat , aes(grain_area_m, logRR, color = "Shannon")) + 
      geom_smooth(data = Shan_dat, formula = y ~ x, aes(grain_area_m, logRR), method=lm , color="#1A1A1A", se=FALSE) +
      scale_color_manual(name = "Index", values = c(Richness = "#9D9D9D", Shannon = "#1A1A1A")) +
      coord_cartesian(xlim = c(NA, NA)) +
      scale_x_continuous(trans = 'log10') +
      ylab("Log response ratio") +
      xlab(expression(paste("Grain size in ", m^2, ""))) +
      theme(panel.background = element_rect(fill = 'white'),
            panel.grid.major = element_line(colour = "lightgrey"),
            panel.grid.minor = element_line(colour = "white"),
            panel.border = element_rect(fill = NA,colour = "black"), 
            plot.background = element_rect(fill = 'white'),
            strip.background = element_rect(fill = "white"),
            plot.title = element_text(size = 14),
            legend.key = element_rect(fill = "white", colour = "black"),
            axis.text.x = element_text(color="black"),
            axis.text.y = element_text(color="black"))
  
    # statistical testing of relationship
        # species richness
            # test for normality: grain area
            SR_dat <- SR_dat %>%
              mutate(grain_area_m_log = log(grain_area_m),)
            ks.test(SR_dat$grain_area_m_log, "pnorm", mean=mean(SR_dat$grain_area_m_log), sd=sd(SR_dat$grain_area_m_log))
            shapiro.test(SR_dat$grain_area_m_log)
            qqnorm(SR_dat$grain_area_m_log)
            qqline(SR_dat$grain_area_m_log)
            # test for normality: log response ratio
            ks.test(SR_dat$logRR, "pnorm", mean=mean(SR_dat$logRR), sd=sd(SR_dat$logRR))
            shapiro.test(SR_dat$logRR)
            qqnorm(SR_dat$logRR)
            qqline(SR_dat$logRR)
            # test for correlation
            cor.test(SR_dat$logRR, SR_dat$grain_area_m_log, method="spearman")
            anova(lm(SR_dat$logRR ~ SR_dat$grain_area_m_log))
            plot(lm(SR_dat$logRR ~ SR_dat$grain_area_m_log))
            summary(lm(SR_dat$logRR ~ SR_dat$grain_area_m_log))
  
        # Shannon
            # test for normality: grain area
            Shan_dat <- Shan_dat %>%
              mutate(grain_area_m_log = log(grain_area_m),)
            shapiro.test(Shan_dat$grain_area_m_log) # no k-s-test as low sample size
            qqnorm(Shan_dat$grain_area_m_log)
            qqline(Shan_dat$grain_area_m_log)
            # test for normality: log response ratio
            ks.test(Shan_dat$logRR, "pnorm", mean=mean(Shan_dat$logRR), sd=sd(Shan_dat$logRR))
            shapiro.test(Shan_dat$logRR)
            qqnorm(Shan_dat$logRR)
            qqline(Shan_dat$logRR)
            # test for correlation
            cor.test(Shan_dat$logRR, Shan_dat$grain_area_m_log, method="spearman")
            anova(lm(Shan_dat$logRR ~ Shan_dat$grain_area_m_log))
            plot(lm(Shan_dat$logRR ~ Shan_dat$grain_area_m_log))
            summary(lm(Shan_dat$logRR ~ Shan_dat$grain_area_m_log))
    
    pdf("grain_to_lrr_lm.pdf", width = 5.25, height = 3.75)
    grid.arrange(grain_lrr)
    dev.off()