#==============================================================================================================
# ANALYSES
# 1. frequentist linear mixed models
#   a. calculate log response ratios
#   b. modeling
#   c. information on dataset
# 2. meta-analytical models
#   a. calculate log response ratios
#   b. calculate standard errors
#   c. modeling
#   d. information on dataset
#==============================================================================================================

# load packages
library(readxl)
library(tidyverse)
library(vegan)
library(dplyr)
library(lme4)
library(lmerTest)
library(MuMIn)
library(ggplot2)
library(grid)
library(gridExtra)
library(glmmTMB)
library(ggeffects)
library(brms)
library(bayestestR)
library(coda)
library(extraDistr)
library(sjPlot)

# read in data
dat1 <- read_xlsx("Biodiv_MPAs_wRepl.xlsx", na = c("","NA"))
dat1$ID <- as.factor(dat1$ID) # change variable to factor

# remove "before" measurements to only compare "protected" vs. "unprotected" (control-impact)
dat2 <- dat1 %>% 
  filter(value_type %in% c("mean","median")) %>%
  filter(!str_detect(protection, "before")) %>%
  filter(double == 0) 

# ============== frequentist linear mixed models ================

# calculate log response ratios ------------------------------------------------------

    # select necessary columns only
    dat3 <- dat2 %>%
      select(ID, name_mpa, protection, fish_3groups, index, value, replicate, grain_area_m) %>% 
      mutate(value = as.numeric(value))
    
    # switch from long to wide format
    dat3_w <- dat3 %>%
      pivot_wider(names_from = protection, values_from = value)
    
    # convert diversity measures to numeric values
    dat3_w <- dat3_w %>%
      mutate(pp = as.numeric(pp),
             oa = as.numeric(oa),
             fp = as.numeric(fp))
    
    # calculate effect sizes
    dat3_w <- dat3_w %>%
      mutate(logRR_pp = log(pp/oa),
             logRR_fp = log(fp/oa),)
    
    # pivot longer to bring data in right format to be joined with explanatory variables
    dat3_l <- dat3_w %>%
      pivot_longer(cols = c(`logRR_fp`,`logRR_pp`), names_to = "protection", values_to = "logRR") %>%
      select(-pp, -oa, -fp) %>%
      drop_na(logRR)
    
    # change names to fit the "expla" table
    dat3_l$protection <- recode_factor(dat3_l$protection, logRR_pp  = "pp", logRR_fp  = "fp")
    
    # create new table with IDs and mpa age and size as explanatory variables
    expla <- dat1 %>%
      select(ID, name_mpa, protection, mpa_age, size_km2) %>%
      distinct() %>%
      na.omit()
    
    # join table with effect sizes and explanatory data
    dat3_l_expla <- dat3_l %>%
      left_join(expla) %>%
      mutate(c_size_log_km2 = log(size_km2) - mean(log(size_km2), na.rm = TRUE)) %>%
      mutate(c_age_log = log(mpa_age) - mean(log(mpa_age), na.rm = TRUE))
    
    dat3_l_expla$fish_3groups <- as.factor(dat3_l_expla$fish_3groups) # change variable to factor


# modeling ------------------------------------------------------------------

    # prepare data for modelling
        # create subsets for species richness and Shannon index
        SR_dat <- dat3_l_expla %>%
          filter(index=='SR') 
        Shan_dat <- dat3_l_expla %>%
          filter(index=='Shannon') 
  
    # fit models
        # species richness
            # null model
            m_SR_null <- lmer(logRR ~ 1 + (1 | ID), data = SR_dat)
            summary(m_SR_null) #pos. effect of protection
      
            # single explanatory variables
                # size
                m_SR_size <- lmer(logRR ~ fish_3groups + c_size_log_km2 + (1 | ID), data = SR_dat)
                m_SR_size_nf <- lmer(logRR ~ c_size_log_km2 + (1 | ID), data = SR_dat)
                summary(m_SR_size)
                  
                    # remove largest MPA
                    m_SR_size_dropBiggest <- lmer(logRR ~ fish_3groups + c_size_log_km2 + (1 | ID), data = SR_dat %>% filter(size_km2 < 3200))
                    summary(m_SR_size_dropBiggest)
                  
                    # remove smallest MPA
                    m_SR_size_dropSmallest <- lmer(logRR ~ fish_3groups + c_size_log_km2 + (1 | ID), data = SR_dat %>% filter(size_km2 > 0.01))
                    summary(m_SR_size_dropSmallest)
                    
                    # remove largest and smallest MPA
                    m_SR_size_dropBoth <- lmer(logRR ~ fish_3groups + c_size_log_km2 + (1 | ID), data = SR_dat %>% filter(size_km2 < 3200 & size_km2 > 0.01))
                    summary(m_SR_size_dropBoth)
                  
                # age
                m_SR_age <- lmer(logRR ~ fish_3groups + c_age_log + (1 | ID), data = SR_dat)
                summary(m_SR_age) #no effect
                
                # protection
                m_SR_protection <- lmer(logRR ~ fish_3groups + protection + (1 | ID), data = SR_dat)
                summary(m_SR_protection) #no effect
    
            # multiple explanatory variables
                # all 3 variables without interaction
                m_SR_3VwoI <- lmer(logRR ~ fish_3groups + protection + c_age_log + c_size_log_km2 + (1 | ID), data = SR_dat)
                summary(m_SR_3VwoI) #as above - only size has an effect
                
                # all 3 variables with all interactions
                m_SR_3VwI <- lmer(logRR ~ (fish_3groups + protection + c_age_log + c_size_log_km2)^2 + (1 | ID), data = SR_dat)
                summary(m_SR_3VwI)
        
        # min. adequate model with AICc
        AICc(m_SR_null,
             m_SR_size,
             m_SR_size_nf,
             m_SR_age,
             m_SR_protection,
             m_SR_3VwoI,
             m_SR_3VwI)
    
        # Shannon diversity
        # ! all but null model: boundary (singular) fit !
  
            # null model
            m_Shan_null <- lmer(logRR ~ 1 + (1 | ID), data = Shan_dat)
            summary(m_Shan_null) #no sign. pos. effect of protection (p = 0.103)
    
            # single explanatory variables
                # size
                m_Shan_size <- lmer(logRR ~ fish_3groups + c_size_log_km2 + (1 | ID), data = Shan_dat)
                summary(m_Shan_size) # size: p = 0.11343; slope = -0.025863 -> same trend although not significant
                
                # age
                m_Shan_age <- lmer(logRR ~ fish_3groups + c_age_log + (1 | ID), data = Shan_dat)
                summary(m_Shan_age) #no effect
                
                #protection
                m_Shan_protection <- lmer(logRR ~ fish_3groups + protection + (1 | ID), data = Shan_dat)
                summary(m_Shan_protection) # p = 0.04194 *; estimate = -0.20042 -> ppas are less effective although not p < 0.5
    
            # multiple explanatory variables
                # all 3 variables without interaction
                m_Shan_3VwoI <- lmer(logRR ~ fish_3groups + protection + c_age_log + c_size_log_km2 + (1 | ID), data = Shan_dat)
                summary(m_Shan_3VwoI) # no sign. effects
                
                # all 3 variables with all interactions
                m_Shan_3VwI <- lmer(logRR ~ (fish_3groups + protection + c_age_log + c_size_log_km2)^2 + (1 | ID), data = Shan_dat)
                summary(m_Shan_3VwI) # no sign. effects

        # min. adequate model with AICc
        AICc(m_Shan_null,
             m_Shan_size,
             m_Shan_age,
             m_Shan_protection,
             m_Shan_3VwoI,
             m_Shan_3VwI)


# dataset information ---------------------------------------------------------------

    # count studies included in the analyses
        # richness -> 35 Studies
        study_no_SR_quan <- SR_dat %>%
          select(ID) %>%
          distinct() %>%
          na.omit()
    
        # Shannon -> 11 Studies
        study_no_Shan_quan <- Shan_dat %>%
          select(ID) %>%
          distinct() %>%
          na.omit()

    # count MPAs included in the analyses 
        # richness -> 72 MPAs
        data_no_SR_quan <- SR_dat %>%
          select(ID, name_mpa, protection) %>%
          distinct() %>%
          na.omit()
        
        # Shannon -> 21 MPAs
        data_no_Shan_quan <- Shan_dat %>%
          select(ID, name_mpa, protection) %>%
          distinct() %>%
          na.omit()

    # count fully and partially protected areas included in the analyses
    SR_dat$protection <- as.factor(SR_dat$protection)
    Shan_dat$protection <- as.factor(Shan_dat$protection)

        # richness -> tot. entries: 116, fp:71; pp:45
        summary(SR_dat) 
        
        # Shannon -> tot. entries: 38, fp:19; pp:19
        summary(Shan_dat)

    # distribution marine protected area size and duration of protection
        # all
            #size
            mean(expla$size_km2)
            median(expla$size_km2)
            max(expla$size_km2)
            min(expla$size_km2)
            
            #age
            mean(expla$mpa_age)
            max(expla$mpa_age)
            min(expla$mpa_age)

        # richness
            # create new table with IDs and mpa age and size
            expla_SR_quan <- SR_dat %>%
              select(ID, name_mpa, protection, mpa_age, size_km2) %>%
              distinct() %>%
              na.omit()
      
            #size
            mean(expla_SR_quan$size_km2)
            median(expla_SR_quan$size_km2)
            max(expla_SR_quan$size_km2)
            min(expla_SR_quan$size_km2)
            
            #age
            mean(expla_SR_quan$mpa_age)
            median(expla_SR_quan$mpa_age)
            max(expla_SR_quan$mpa_age)
            min(expla_SR_quan$mpa_age)

    # information on surveyed fishgroups by ID (study)
        # richness
        studies_fishgroups_SR <- SR_dat %>%
          select(ID, fish_3groups) %>%
          distinct() %>%
          na.omit()
        
        # Shannon
        studies_fishgroups_Shan <- Shan_dat %>%
          select(ID, fish_3groups) %>%
          distinct() %>%
          na.omit()

    # information on used indices
    dat_quan <- read_xlsx("Biodiv_MPAs_ONLYquan.xlsx", na = c("","NA"))
    dat_quan$ID <- as.factor(dat_quan$ID)
    
    dat_quan2 <- dat_quan %>% 
      filter(value_type %in% c("mean","median")) %>%
      filter(!str_detect(protection, "before")) %>%
      filter(double == 0) 
    
    indices <- dat_quan2 %>%
      select(ID, index) %>%
      distinct() %>%
      na.omit()
    
    indices_count <- indices %>% group_by(index) %>%
      summarise(n_studies = n_distinct(ID))

    # information on surveyed habitats
    dat_quan3 <- dat_quan2 %>% 
      filter(index %in% c("SR","Shannon"))
    
    habitats <- dat_quan3 %>%
      select(ID, habitat_short) %>%
      distinct()
    
    habitats_count <- habitats %>% group_by(habitat_short) %>%
      summarise(n_studies = n_distinct(ID))

    
# ============== metaanalytic models ================
    
# prepare data ------------------------------------------------------
    
dat1b <- read_xlsx("Biodiv_MPAs_wRepl.xlsx", na = c("","NA"))
dat1b$ID <- as.factor(dat1b$ID)

    # remove "before" measurements to only compare "protected" vs. "unprotected" (control-impact) 
    # & delete all entries without suitable error estimate
    dat2b <- dat1b %>% 
      filter(value_type %in% c("mean","median")) %>%
      filter(!str_detect(protection, "before")) %>%
      filter(double == 0)
    dat2b <- dat2b[!is.na(dat2b$SE_new),]


# calculate log response ratios -------------------------------------
    
    # select necessary columns only
    dat3b <- dat2b %>%
      select(ID, name_mpa, protection, fish_3groups, index, value, replicate) %>% 
      mutate(value = as.numeric(value))
    
    # switch from long to wide format
    dat3b_w0 <- dat3b %>%
      pivot_wider(names_from = protection, values_from = value)
    
    # Convert diversity measures to numeric values
    dat3b_w0 <- dat3b_w0 %>%
      mutate(pp = as.numeric(pp),
             oa = as.numeric(oa),
             fp = as.numeric(fp))
    
    # Calculate effect sizes
    dat3b_w <- dat3b_w0 %>%
      mutate(logRR_pp = log(pp/oa),
             logRR_fp = log(fp/oa),)
    
    # pivot longer to bring data in right format to be joined with explanatory variables
    dat3b_l <- dat3b_w %>%
      pivot_longer(cols = c(`logRR_fp`,`logRR_pp`), names_to = "protection", values_to = "logRR") %>%
      select(-pp, -oa, -fp) %>%
      na.omit()
    
    # change names to fit the "expla" table
    dat3b_l$protection <- recode_factor(dat3b_l$protection, logRR_pp  = "pp", logRR_fp  = "fp")

    
# calculate standard errors -----------------------------------------
    
    # select necessary columns only
    dat3bse <- dat2b %>%
      select(ID, name_mpa, protection, fish_3groups, SE_new, replicate, index, no_samples) %>% 
      mutate(SE_new = as.numeric(SE_new)) %>% 
      mutate(no_samples = as.numeric(no_samples))
    
    # switch from long to wide format
    dat3b_wse <- dat3bse %>%
      pivot_wider(names_from = protection, values_from = c(SE_new, no_samples))
    
    # Convert SEs and no. of samples to numeric values
    dat3b_wse <- dat3b_wse %>%
      mutate(SE_new_pp = as.numeric(SE_new_pp),
             SE_new_fp = as.numeric(SE_new_fp),
             SE_new_oa = as.numeric(SE_new_oa),
             no_samples_pp = as.numeric(no_samples_pp),
             no_samples_fp = as.numeric(no_samples_fp),
             no_samples_oa = as.numeric(no_samples_oa))
    
    # inclue mean values
    dat4b_wse <- left_join(dat3b_w0, dat3b_wse)
    
    # Calculate effect size error estimates
    dat4b_wse <- dat4b_wse %>%
      mutate(SE_pp = sqrt(((SE_new_pp^2)/((no_samples_pp)*(pp^2)))+((SE_new_oa^2)/((no_samples_oa)*(oa^2)))),
             SE_fp = sqrt(((SE_new_fp^2)/((no_samples_fp)*(fp^2)))+((SE_new_oa^2)/((no_samples_oa)*(oa^2)))),)

    
# combine ----------------------------------------------------------
    
    # pivot longer to bring data in right format to be joined with explanatory variables and log response ratios
    dat4b_lse <- dat4b_wse %>%
      pivot_longer(cols = c(`SE_fp`,`SE_pp`), names_to = "protection", values_to = "SE") %>%
      select(-pp, -oa, -fp, -SE_new_pp, -SE_new_oa, -SE_new_fp, -no_samples_pp, -no_samples_oa, -no_samples_fp) %>%
      na.omit()
    
    # change names to fit the log response ratio table
    dat4b_lse$protection <- recode_factor(dat3b_l$protection, SE_pp  = "pp", SE_fp  = "fp")
    
    # join log respone ratios and standard errors
    dat_brms <- left_join(dat4b_lse, dat3b_l)
    
    # create new table with IDs and mpa age and size as explanatory variables
    expla_b <- dat1b %>%
      select(ID, name_mpa, protection, mpa_age, size_km2) %>%
      distinct() %>%
      na.omit()
    
    # join table with effect sizes and explanatory data
    dat_brms_expla <- dat_brms %>%
      left_join(expla_b) %>%
      mutate(c_size_log_km2 = log(size_km2) - mean(log(size_km2), na.rm = TRUE)) %>%
      mutate(c_age_log = log(mpa_age) - mean(log(mpa_age), na.rm = TRUE))
    
    dat_brms_expla$fish_3groups <- as.factor(dat_brms_expla$fish_3groups)
    dat_brms_expla$protection <- as.factor(dat_brms_expla$protection)

    
# modeling ---------------------------------------------------------
    
    # create subsets for species richness and Shannon index
    SR_dat_brms <- dat_brms_expla %>%
      filter(index=='SR') 
        
    Shan_dat_brms <- dat_brms_expla %>%
      filter(index=='Shannon') 

    # fit models
    priors <- c(prior(normal(0,1), class = Intercept),
                prior(cauchy(0,0.5), class = sd))

        # species richness
            # null model
            brm_SR_null <- brm(logRR | se(SE) ~ 1 + (1 | ID), family = gaussian(), data = SR_dat_brms, prior = priors, cores = 4, chains = 4, iter = 4000, algorithm = "sampling")
            summary(brm_SR_null)
            ci(brm_SR_null, method = "ETI")
            plot(brm_SR_null)
            pp_check(brm_SR_null)
            
            # single explanatory variables
                # size
                brm_SR_size <- brm(logRR | se(SE) ~ fish_3groups + c_size_log_km2 + (1 | ID), family = gaussian(), data = SR_dat_brms, prior = priors, cores = 4, chains = 4, iter = 4000)
                summary(brm_SR_size)
                ci(brm_SR_size, method = "ETI")
                plot(brm_SR_size)
                pp_check(brm_SR_size)
                
                # age
                brm_SR_age <- brm(logRR | se(SE) ~ fish_3groups + c_age_log + (1 | ID), family = gaussian(), data = SR_dat_brms, prior = priors, cores = 4, chains = 4, iter = 4000, control = list(adapt_delta = 0.95))
                summary(brm_SR_age)
                ci(brm_SR_age, method = "ETI")
                plot(brm_SR_age)
                pp_check(brm_SR_age)
                
                # protection
                brm_SR_protection <- brm(logRR | se(SE) ~ fish_3groups + protection + (1 | ID), family = gaussian(), data = SR_dat_brms, prior = priors, cores = 4, chains = 4, iter = 4000)
                summary(brm_SR_protection)
                ci(brm_SR_protection, method = "ETI")
                plot(brm_SR_protection)
                pp_check(brm_SR_protection)

        # Shannon
            # null model
            brm_Shan_null <- brm(logRR | se(SE) ~ 1 + (1 | ID), family = gaussian(), data = Shan_dat_brms, prior = priors, cores = 4, chains = 4, iter = 4000, control = list(adapt_delta = 0.99))
            summary(brm_Shan_null)
            ci(brm_Shan_null, method = "ETI")
            plot(brm_Shan_null)
            pp_check(brm_Shan_null)
            
            # single explanatory variables
                # size
                brm_Shan_size <- brm(logRR | se(SE) ~ fish_3groups + c_size_log_km2 + (1 | ID), family = gaussian(), data = Shan_dat_brms, prior = priors, cores = 4, chains = 4, iter = 4000, control = list(adapt_delta = 0.99))
                summary(brm_Shan_size)
                plot(brm_Shan_size)
                pp_check(brm_Shan_size)
                
                # age
                brm_Shan_age <- brm(logRR | se(SE) ~ fish_3groups + c_age_log + (1 | ID), family = gaussian(), data = Shan_dat_brms, prior = priors, cores = 4, chains = 4, iter = 4000, control = list(adapt_delta = 0.99))
                summary(brm_Shan_age)
                plot(brm_Shan_age)
                pp_check(brm_Shan_age)
                
                # protection
                brm_Shan_protection <- brm(logRR | se(SE) ~ fish_3groups + protection + (1 | ID), family = gaussian(), data = Shan_dat_brms, prior = priors, cores = 4, chains = 4, iter = 4000, control = list(adapt_delta = 0.99))
                summary(brm_Shan_protection)
                plot(brm_Shan_protection)
                pp_check(brm_Shan_protection)

    #save(brm_SR_null, brm_SR_size, brm_SR_age, brm_SR_protection, brm_Shan_null, file = 'brm_models_new.Rdata')

                
# dataset information --------------------------------------------------------------
      
    # count studies included in the analyses
        # richness -> 29 Studies
        study_no_SR_quan_brms <- SR_dat_brms %>%
          select(ID) %>%
          distinct() %>%
          na.omit()
        
        # Shannon -> 9
        study_no_H_quan_brms <- Shan_dat_brms %>%
          select(ID) %>%
          distinct() %>%
          na.omit()

    # Count MPAs included in the analyses
        # richness -> 58
        data_no_SR_quan_brms <- SR_dat_brms %>%
          select(ID, name_mpa, protection) %>%
          distinct() %>%
          na.omit()
        
        # Shannon -> 15
        data_no_H_quan_brms <- Shan_dat_brms %>%
          select(ID, name_mpa, protection) %>%
          distinct() %>%
          na.omit()

    # distribution marine protected area size and duration of protection
        # richness
            # Create new table with IDs and mpa age and size
            expla_SR_quan_brms <- SR_dat_brms %>%
              select(ID, name_mpa, protection, mpa_age, size_km2) %>%
              distinct() %>%
              na.omit()

            #size
            mean(expla_SR_quan_brms$size_km2)
            median(expla_SR_quan_brms$size_km2)
            max(expla_SR_quan_brms$size_km2)
            min(expla_SR_quan_brms$size_km2)
            
            #age
            mean(expla_SR_quan_brms$mpa_age)
            max(expla_SR_quan_brms$mpa_age)
            min(expla_SR_quan_brms$mpa_age)